@@ -2,11 +2,12 @@
 //
 // NB: It only works on a GNOME (based) system.
 //
-// Usage is simple. Either pass a '+' as argument or no argument on commandline, and it incresses
+// Usage is simple. Either pass a '+' as argument or no argument on commandline, and it increases
 // the brightness by 5%. Pass '-' for decreasing it by 5%.
 
 fn main() {
-    let connection = zbus::Connection::new_session().unwrap();
+    tracing_subscriber::fmt::init();
+    let connection = zbus::blocking::Connection::session().unwrap();
 
     let method = match std::env::args().nth(1) {
         Some(s) => {
@@ -31,6 +32,6 @@ fn main() {
         )
         .unwrap();
 
-    let (percent, _) = reply.body::<(u32, &str)>().unwrap();
-    println!("New level: {}%", percent);
+    let (percent, _) = reply.body().deserialize::<(i32, &str)>().unwrap();
+    println!("New level: {percent}%");
 }
